@@ -8,11 +8,17 @@ from .projected_gradient_descent import (  # noqa: F401
     L1ProjectedGradientDescentAttack,
     L2ProjectedGradientDescentAttack,
     LinfProjectedGradientDescentAttack,
+    L1AdamProjectedGradientDescentAttack,
+    L2PAdamProjectedGradientDescentAttack,
+    LinfAdamProjectedGradientDescentAttack,
 )
 from .basic_iterative_method import (  # noqa: F401
     L1BasicIterativeAttack,
     L2BasicIterativeAttack,
     LinfBasicIterativeAttack,
+    L1AdamBasicIterativeAttack,
+    L2AdamBasicIterativeAttack,
+    LinfAdamBasicIterativeAttack,
 )
 from .fast_gradient_method import (  # noqa: F401
     L1FastGradientAttack,
@@ -57,7 +63,14 @@ from .brendel_bethge import (  # noqa: F401
     L2BrendelBethgeAttack,
     LinfinityBrendelBethgeAttack,
 )
+from .fast_minimum_norm import (  # noqa: F401
+    L0FMNAttack,
+    L1FMNAttack,
+    L2FMNAttack,
+    LInfFMNAttack,
+)
 from .gen_attack import GenAttack  # noqa: F401
+from .pointwise import PointwiseAttack  # noqa: F401
 
 # from .blended_noise import LinearSearchBlendedUniformNoiseAttack  # noqa: F401
 # from .brendel_bethge import (  # noqa: F401
@@ -80,3 +93,8 @@ L1PGD = L1ProjectedGradientDescentAttack
 L2PGD = L2ProjectedGradientDescentAttack
 LinfPGD = LinfProjectedGradientDescentAttack
 PGD = LinfPGD
+
+L1AdamPGD = L1ProjectedGradientDescentAttack
+L2AdamPGD = L2ProjectedGradientDescentAttack
+LinfAdamPGD = LinfProjectedGradientDescentAttack
+AdamPGD = LinfAdamPGD
